@@ -1,3 +1,5 @@
 from .file_io import FileIO
 from .hdfs import Hdfs
+from .minio import Minio
+from .http import Http
 from .filesystem import Filesystem
\ No newline at end of file
