@@ -12,11 +12,11 @@ class Filesystem(FileIO):
     def __init__(self, storage_type=None):
         super().__init__()
 
-    def upload(self, local_path, remote_path, overwrite=True):
+    def upload(self, local_path, remote_path):
         self.copy_tree_or_file(local_path, remote_path)
         print("Faking upload because it's running locally.")
 
-    def download(self, remote_path, local_path, overwrite=True):
+    def download(self, remote_path, local_path):
         self.copy_tree_or_file(remote_path, local_path)
         print("Faking download because it's running locally.")
 
