@@ -13,16 +13,16 @@ class Hdfs(FileIO):
         super().__init__()
         self.web_hdfs_url = get_argument('webHdfsUrl')
 
-    def upload(self, local_path, remote_path, overwrite=True):
+    def upload(self, local_path, remote_path):
         # Upload model to HDFS
         client = InsecureClient(self.web_hdfs_url)
-        client.upload(remote_path, local_path, overwrite=overwrite, temp_dir="/tmp")
+        client.upload(remote_path, local_path, overwrite=True, temp_dir="/tmp")
         client.set_permission(remote_path, "777")
 
-    def download(self, remote_path, local_path, overwrite=True):
+    def download(self, remote_path, local_path):
         # Dowload model from HDFS to disk
         client = InsecureClient(self.web_hdfs_url)
-        client.download(remote_path, local_path, overwrite=overwrite, temp_dir="/tmp")
+        client.download(remote_path, local_path, overwrite=True, temp_dir="/tmp")
 
     def get_modification_time(self, path):
         # Get time when last modified
